export default {
  server: {
    port: 5000,
  },
  /*
   ** Nuxt rendering mode
   ** See https://nuxtjs.org/api/configuration-mode
   */
  mode: 'spa',
  /*
   ** Nuxt target
   ** See https://nuxtjs.org/api/configuration-target
   */
  target: 'static',
  /*
   ** Headers of the page
   ** See https://nuxtjs.org/api/configuration-head
   */
  head: {
    title: process.env.npm_package_name || '',
    meta: [
      { charset: 'utf-8' },
      { name: 'viewport', content: 'width=device-width, initial-scale=1' },
      {
        hid: 'description',
        name: 'description',
        content: process.env.npm_package_description || '',
      },
    ],
    link: [{ rel: 'icon', type: 'image/x-icon', href: '/favicon.ico' },{ rel: 'stylesheet', href: 'https://fonts.googleapis.com/css?family=Roboto' }],
  },
  /*
   ** Global CSS
   */
  css: ['element-ui/lib/theme-chalk/index.css','postcss/docs/api/assets/styles.min.css'],
  /*
   ** Plugins to load before mounting the App
   ** https://nuxtjs.org/guide/plugins
   */
  plugins: ['@/plugins/element-ui','@/plugins/vue-cookies','@/plugins/global','@/plugins/moment','@/plugins/contextmenu','@/plugins/uuid'],
  /*
   ** Auto import components
   ** See https://nuxtjs.org/api/configuration-components
   */
  components: true,
  /*
   ** Nuxt.js dev-modules
   */
  buildModules: [
    '@nuxt/typescript-build',
    // Doc: https://github.com/nuxt-community/stylelint-module
    '@nuxtjs/stylelint-module',
  ],
  /*
   ** Nuxt.js modules
   */
  modules: [
    // Doc: https://axios.nuxtjs.org/usage
    '@nuxtjs/axios',
    '@nuxtjs/pwa',
    // Doc: https://github.com/nuxt/content
    '@nuxt/content',
    'nuxt-i18n'
  ],
  /*
   ** Axios module configuration
   ** See https://axios.nuxtjs.org/options
   */
  axios: {},
  /*
   ** Content module configuration
   ** See https://content.nuxtjs.org/configuration
   */
  content: {},
  /*
   ** Build configuration
   ** See https://nuxtjs.org/api/configuration-build/
   */
  build: {
    transpile: [/^element-ui/],
  },
  i18n: {
    locales: ['zhCN', 'en'],
    defaultLocale: 'zhCN',
    vueI18n: {
      fallbackLocale: 'zhCN',
      messages: {
        "zhCN": {
          "account": {
            "form": {
              "confirmPwd": "确认密码",
              "password": "密码",
              "tip": {
                "login_fail": "登陆失败，账号或密码错误",
                "login_ok": "登录成功",
                "register_fail": "注册失败",
                "register_ok": "注册成功",
                "tow_diff": "两次输入密码不一致!",
                "user_exit": "用户{name}已存在",
                "valid_account": "帐号密码正确"
              },
              "user": "帐号"
            },
            "login": "登录",
            "register": "注册"
          },
          "action": "操作",
          "app_name": "云笔记",
          "button": {
            "add": "添加",
            "cancel": "取消",
            "catalog": "目录",
            "del": "删除",
            "edit": "编辑",
            "jump_note": "定位笔记",
            "ok": "确定",
            "query": "查询",
            "rating": "提交评分",
            "submit": "提交"
          },
          "center": {
            "collect": {
              "form": {
                "time": "收藏时间",
                "title": "论文标题"
              },
              "name": "我的收藏"
            },
            "myupload": {
              "form": {
                "time": "上传时间",
                "title": "论文标题"
              },
              "name": "我的上传"
            },
            "security": {
              "confirmpwd": "确认新密码",
              "name": "帐号安全",
              "newpwd": "新密码",
              "oldpwd": "原密码",
              "rules": {
                "password": "长度在 {min} 到 {max} 个字符之间"
              },
              "tip": {
                "fail": "密码修改失败",
                "ok": "密码修改成功，请重新登录",
                "same_err": "新密码不能和旧密码一致"
              }
            }
          },
          "choose_lang": "选择语言",
          "document": {
            "doc_list": {
              "year": "（学位年度）"
            },
            "form": {
              "author": "作者",
              "content": "正文内容",
              "end_year": "结束年份",
              "profession": "学科专业",
              "school": "学校",
              "start_year": "开始年份",
              "tag": "标签",
              "title": "标题",
              "tutor": "导师"
            },
            "tip": {
              "doc_empty": "没有匹配到一篇论文",
              "recommend_empty": "暂无论文推荐"
            }
          },
          "en": "英文",
          "error_404": "页面不存在",
          "error_500": "发生严重异常，请联系管理员",
          "form_err": "表单校验失败，请检查表单内容",
          "hide_more_query": "隐藏更多查询",
          "input_confirm": "请确认{keyword}",
          "input_please": "请输入{keyword}",
          "logout": "注销登录",
          "menus": {
            "center": "个人中心",
            "document": "文档",
            "note": "笔记列表",
            "read": "阅读论文",
            "upload": "本地上传论文"
          },
          "more_query": "更多查询",
          "new_recommend": "最新推荐",
          "note": {
            "table": {
              "original_text": "注释原文",
              "paper_name": "论文标题"
            },
            "tip": {
              "confirm_del": "此操作将永久删除该笔记，是否继续？"
            }
          },
          "read": {
            "contextmenu": {
              "add": "添加笔记",
              "search": "查找"
            },
            "form": {
              "keyword": "关键字",
              "note_content": "笔记内容",
              "note_title": "笔记标题"
            },
            "tip": {
              "add_tip": "是否添加该笔记？",
              "add_tip_fail": "笔记添加失败",
              "add_tip_ok": "笔记添加成功",
              "auto_save": "失去焦点自动保存",
              "cancel_collect": "取消收藏",
              "cancel_collect_fail": "取消收藏失败",
              "cancel_collect_ok": "取消收藏成功",
              "click_note_list": "单击卡片定位笔记",
              "collect": "收藏",
              "collect_fail": "收藏失败",
              "collect_ok": "收藏成功",
              "contextmenu_err": "请选中文本进行操作",
              "del_confirm": "确认删除此笔记？",
              "note_zero": "还没有任何笔记，尝试正文选中文本右击添加一个笔记吧！",
              "rating_1": "本文对您的科研工作是否有帮助",
              "rating_2": "本文的内容是否科学严谨",
              "rating_3": "您对本文的推荐程度",
              "rating_ok": "评价成功",
              "search_next": "查找下一个",
              "search_prev": "查找上一个",
              "search_zero": "正文中没有 ‘{keyword}’",
              "update_note_fail": "笔记保存失败",
              "update_note_ok": "笔记保存成功"
            }
          },
          "reading_online": "在线阅读",
          "reset": "重置",
          "select_please": "请选择{keyword}",
          "tip": "提示",
          "unknown_error": "未知错误",
          "upload": {
            "form": {
              "author": "论文作者",
              "content": "正文内容",
              "profession": "学科专业",
              "remove": "确定移除{file}",
              "school": "学校",
              "summary": "摘要",
              "tag": "论文标签",
              "title": "论文标题",
              "type": "论文类型",
              "upload": "点击上传",
              "upload_tip": "只能上传txt",
              "year": "学位年度"
            },
            "tip": {
              "ok": "论文上传成功"
            }
          },
          "upload_please": "请上传{keyword}",
          "user": "帐号",
          "zhCN": "简体中文"
        },
        "en": {
          "account": {
            "form": {
              "confirmPwd": "",
              "password": "",
              "tip": {
                "login_fail": "",
                "login_ok": "",
                "register_fail": "",
                "register_ok": "",
                "tow_diff": "",
                "user_exit": "",
                "valid_account": ""
              },
              "user": ""
            },
            "login": "",
            "register": ""
          },
          "action": "",
          "app_name": "cloudnote",
          "button": {
            "add": "",
            "cancel": "",
            "catalog": "",
            "del": "",
            "edit": "",
            "jump_note": "",
            "ok": "",
            "query": "",
            "rating": "",
            "submit": ""
          },
          "center": {
            "collect": {
              "form": {
                "time": "",
                "title": ""
              },
              "name": ""
            },
            "myupload": {
              "form": {
                "time": "",
                "title": ""
              },
              "name": ""
            },
            "security": {
              "confirmpwd": "",
              "name": "",
              "newpwd": "",
              "oldpwd": "",
              "rules": {
                "password": ""
              },
              "tip": {
                "fail": "",
                "ok": "",
                "same_err": ""
              }
            }
          },
          "choose_lang": "language",
          "document": {
            "doc_list": {
              "year": ""
            },
            "form": {
              "author": "",
              "content": "",
              "end_year": "",
              "profession": "",
              "school": "",
              "start_year": "",
              "tag": "",
              "title": "",
              "tutor": ""
            },
            "tip": {
              "doc_empty": "",
              "recommend_empty": ""
            }
          },
          "en": "english",
          "error_404": "",
          "error_500": "",
          "form_err": "",
          "hide_more_query": "",
          "input_confirm": "",
          "input_please": "",
          "logout": "",
          "menus": {
            "center": "",
            "document": "document",
            "note": "note list",
            "read": "",
            "upload": ""
          },
          "more_query": "",
          "new_recommend": "",
          "note": {
            "table": {
              "original_text": "",
              "paper_name": ""
            },
            "tip": {
              "confirm_del": ""
            }
          },
          "read": {
            "contextmenu": {
              "add": "",
              "search": ""
            },
            "form": {
              "keyword": "",
              "note_content": "",
              "note_title": ""
            },
            "tip": {
              "add_tip": "",
              "add_tip_fail": "",
              "add_tip_ok": "",
              "auto_save": "",
              "cancel_collect": "",
              "cancel_collect_fail": "",
              "cancel_collect_ok": "",
              "click_note_list": "",
              "collect": "",
              "collect_fail": "",
              "collect_ok": "",
              "contextmenu_err": "",
              "del_confirm": "",
              "note_zero": "",
              "rating_1": "",
              "rating_2": "",
              "rating_3": "",
              "rating_ok": "",
              "search_next": "",
              "search_prev": "",
              "search_zero": "",
              "update_note_fail": "",
              "update_note_ok": ""
            }
          },
          "reading_online": "",
          "reset": "",
          "select_please": "",
          "tip": "",
          "unknown_error": "",
          "upload": {
            "form": {
              "author": "",
              "content": "",
              "profession": "",
              "remove": "",
              "school": "",
              "summary": "",
              "tag": "",
              "title": "",
              "type": "",
              "upload": "",
              "upload_tip": "",
              "year": ""
            },
            "tip": {
              "ok": ""
            }
          },
          "upload_please": "",
          "user": "",
          "zhCN": "Simplified Chinese"
        }
      }
    }
  }
}
